@@ -139,8 +139,8 @@ class MyModuleFinder(mf27.ModuleFinder):
         self._add_import(module)
         return module
 
-    def load_module(self, fqname, fp, pathname, xxx_todo_changeme):
-        (suffix, mode, kind) = xxx_todo_changeme
+    def load_module(self, fqname, fp, pathname, suffix_mode_kind):
+        (suffix, mode, kind) = suffix_mode_kind
         try:
             module = mf27.ModuleFinder.load_module(
                 self, fqname, fp, pathname, (suffix, mode, kind)
@@ -150,6 +150,13 @@ class MyModuleFinder(mf27.ModuleFinder):
             # an `if six.PY3`
             # print "SYNTAX_ERROR"
             module = None
+        except AttributeError as e:
+            # See issues #139 and #140...
+            print("ERROR trying to load {} from {} (py38+ _find_module reimplementation of imp.find_module called .is_package on None...)\n{}".format(
+                fqname, pathname,
+                e
+            ))
+            module = None
 
         if module is not None:
             self._types[module.__name__] = kind
